@@ -52,9 +52,9 @@
 #include <QPushButton>
 #include <QMessageBox>
 
-// KDE includes
+// KF includes
 
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 /// This is all libkipi headers included in this tool.
 
@@ -74,7 +74,7 @@ namespace KIPIKXMLHelloWorldPlugin
 {
 
 /** Under Kipi-plugins, you can use KPToolDialog class from kipi-plugins to display plugin dialogs. It offers some facilities to
-    set data and rules about plugins, especially to wrap properlly tool with KDE bugilla. We use KPAboutData container
+    set data and rules about plugins, especially to wrap properly tool with KDE bugzilla. We use KPAboutData container
     for that.
 */
 
@@ -89,13 +89,13 @@ public:
     {
         /// It's always clean to init pointers to zero. If crash appear,
         /// debugger will show a null pointer instead a non initialized one.
-        actionImages = 0;
-        actionTools  = 0;
-        actionExport = 0;
-        actionImport = 0;
+        actionImages = nullptr;
+        actionTools  = nullptr;
+        actionExport = nullptr;
+        actionImport = nullptr;
     }
 
-    /** These plugin actions will pluged into menu KIPI host application.
+    /** These plugin actions will plugged into menu KIPI host application.
      */
     QAction* actionImages;
     QAction* actionTools;
@@ -110,7 +110,7 @@ public:
  */
 K_PLUGIN_FACTORY(KXMLHelloWorldFactory, registerPlugin<Plugin_KXMLHelloWorld>();)
 
-/** The plugin constructor. Note that plugin name passed as string in 3rd arguement of KIPI::Plugin parent class
+/** The plugin constructor. Note that plugin name passed as string in 3rd argument of KIPI::Plugin parent class
  *  is the same than Name value from .desktop file.
  */
 Plugin_KXMLHelloWorld::Plugin_KXMLHelloWorld(QObject* const parent, const QVariantList&)
@@ -167,7 +167,7 @@ void Plugin_KXMLHelloWorld::setupActions()
      *  about already existing one from other tool to prevent conflict.
      *  Don't forget to define an unique string name to your action, to be able to disable it
      *  in KIPI host application if necessary. You must check of course name already used in
-     *  others tool before to prevent redondancy.
+     *  others tool before to prevent redundancy.
      */
 
     /** We need to call setDefaultCategory in case the plugin loader cannot
@@ -262,7 +262,7 @@ void Plugin_KXMLHelloWorld::slotActivateActionImages()
         foreach (const QUrl& url, images.images())
             names << url.fileName();
 
-        QMessageBox::information(0, QLatin1String("This is the list of selected items"), names.join(QString::fromLatin1("\n")));
+        QMessageBox::information(nullptr, QLatin1String("This is the list of selected items"), names.join(QString::fromLatin1("\n")));
     }
 }
 
@@ -271,7 +271,7 @@ void Plugin_KXMLHelloWorld::slotActivateActionTools()
     /** When actionTools is actived, we display a dedicated widget to select albums from kipi host application
      *  for post processing purpose. When selection is done, we display it in a message box.
      */
-    QPointer<QDialog> dlg                   = new QDialog(0);
+    QPointer<QDialog> dlg                   = new QDialog(nullptr);
     ImageCollectionSelector* const selector = interface()->imageCollectionSelector(dlg);
     QDialogButtonBox* const buttons         = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dlg);
     QVBoxLayout* const vbox                 = new QVBoxLayout(dlg);
@@ -296,7 +296,7 @@ void Plugin_KXMLHelloWorld::slotActivateActionTools()
         foreach (const ImageCollection& col, list)
             names << col.name();
 
-        QMessageBox::information(0, QLatin1String("This is the list of selected albums"), names.join(QString::fromLatin1("\n")));
+        QMessageBox::information(nullptr, QLatin1String("This is the list of selected albums"), names.join(QString::fromLatin1("\n")));
     }
 
     delete dlg;
@@ -308,7 +308,7 @@ void Plugin_KXMLHelloWorld::slotActivateActionExport()
      *  and permit to manage current items selection from kipi host application for batch post-processing purpose.
      */
 
-    QMessageBox::information(0, QLatin1String("Information"), QLatin1String("Plugin_KXMLHelloWorld::slotActivateActionExport() activated"));
+    QMessageBox::information(nullptr, QLatin1String("Information"), QLatin1String("Plugin_KXMLHelloWorld::slotActivateActionExport() activated"));
 }
 
 void Plugin_KXMLHelloWorld::slotActivateActionImport()
@@ -323,7 +323,7 @@ void Plugin_KXMLHelloWorld::slotActivateActionImport()
          */
     }
 
-    QMessageBox::information(0, QLatin1String("Information"), QLatin1String("Plugin_KXMLHelloWorld::slotActivateActionImport() activated"));
+    QMessageBox::information(nullptr, QLatin1String("Information"), QLatin1String("Plugin_KXMLHelloWorld::slotActivateActionImport() activated"));
 }
 
 }  // namespace KIPIHelloWorldPlugin
